SWDEV-332969 - [ABI Break]remove hiparray from tests

- replace with hipArray_t

Signed-off-by: sdashmiz <shadi.dashmiz@amd.com>
Change-Id: Ie1dade58d868182309caf00bf65a86a8fed2cfa6
This commit is contained in:
sdashmiz
2023-09-15 14:44:12 -04:00
committed by Shadi Dashmiz
parent cc35feba07
commit e161374c31
45 changed files with 138 additions and 390 deletions
@@ -47,7 +47,7 @@ TEST_CASE("Unit_hipMemcpy2DFromArrayAsync_Basic") {
CHECK_IMAGE_SUPPORT
HIP_CHECK(hipSetDevice(0));
hipArray *A_d{nullptr};
hipArray_t A_d{nullptr};
size_t width{sizeof(float)*NUM_W};
float *A_h{nullptr}, *hData{nullptr};
hipStream_t stream;
@@ -93,7 +93,7 @@ TEST_CASE("Unit_hipMemcpy2DFromArrayAsync_ExtentValidation") {
CHECK_IMAGE_SUPPORT
HIP_CHECK(hipSetDevice(0));
hipArray *A_d{nullptr};
hipArray_t A_d{nullptr};
size_t width{sizeof(float)*NUM_W};
float *A_h{nullptr}, *hData{nullptr}, *valData{nullptr};
hipStream_t stream;
@@ -174,7 +174,7 @@ TEST_CASE("Unit_hipMemcpy2DFromArrayAsync_PinnedHostMemSameGpu") {
CHECK_IMAGE_SUPPORT
HIP_CHECK(hipSetDevice(0));
hipArray *A_d{nullptr};
hipArray_t A_d{nullptr};
constexpr auto def_val{10};
size_t width{sizeof(float)*NUM_W};
float *A_h{nullptr}, *PinnMem{nullptr};
@@ -228,7 +228,7 @@ TEST_CASE("Unit_hipMemcpy2DFromArrayAsync_multiDevicePinnedHostMem") {
HIP_CHECK(hipDeviceCanAccessPeer(&canAccessPeer, 0, 1));
if (canAccessPeer) {
HIP_CHECK(hipSetDevice(0));
hipArray *A_d{nullptr};
hipArray_t A_d{nullptr};
size_t width{sizeof(float)*NUM_W};
float *A_h{nullptr}, *E_h{nullptr};
hipStream_t stream;
@@ -290,7 +290,7 @@ TEST_CASE("Unit_hipMemcpy2DFromArrayAsync_multiDeviceContextChange") {
HIP_CHECK(hipDeviceCanAccessPeer(&canAccessPeer, 0, 1));
if (canAccessPeer) {
HIP_CHECK(hipSetDevice(0));
hipArray *A_d{nullptr};
hipArray_t A_d{nullptr};
size_t width{sizeof(float)*NUM_W};
float *A_h{nullptr}, *hData{nullptr};
hipStream_t stream;
@@ -333,7 +333,7 @@ TEST_CASE("Unit_hipMemcpy2DFromArrayAsync_Negative") {
CHECK_IMAGE_SUPPORT
HIP_CHECK(hipSetDevice(0));
hipArray *A_d{nullptr};
hipArray_t A_d{nullptr};
size_t width{sizeof(float)*NUM_W};
float *A_h{nullptr}, *hData{nullptr};
hipStream_t stream;